# Changelog

## 0.3 (2020-09-17)

- 📦 Improve packaging
- 👷 Add code linting and improve CI
- ♻️ Refactorings


## 0.2 (2020-09-02)

- ✨ Make sure env vars can be read
- ✅ Add tests for `load_settings()`


## 0.1 (2020-08-28)

- 🎉 Initial PoC
